@@ -8,57 +8,56 @@
 #ifndef KUISERVERJOBTRACKER_H
 #define KUISERVERJOBTRACKER_H
 
-#include <KJobTrackerInterface>
 #include <kjobwidgets_export.h>
 
-#include <memory>
+#if KJOBWIDGETS_ENABLE_DEPRECATED_SINCE(6, 17)
+
+#include <KJobTrackerInterface>
 
 class KJob;
 
-/**
- * @class KUiServerJobTracker kuiserverjobtracker.h KUiServerJobTracker
+/*!
+ * \class KUiServerJobTracker
  *
- * The interface to implement to track the progresses of a job.
+ * \inmodule KJobWidgets
+ *
+ * \brief The interface to implement to track the progresses of a job.
+ * \deprecated[6.17]
+ * Use KUiServerV2JobTracker
  */
-class KJOBWIDGETS_EXPORT KUiServerJobTracker : public KJobTrackerInterface
+class KJOBWIDGETS_EXPORT KJOBWIDGETS_DEPRECATED_VERSION(6, 17, "Use KUiServerV2JobTracker") KUiServerJobTracker : public KJobTrackerInterface
 {
     Q_OBJECT
 
 public:
-    /**
+    /*!
      * Creates a new KJobTrackerInterface
      *
-     * @param parent the parent object
+     * \a parent the parent object
      */
     explicit KUiServerJobTracker(QObject *parent = nullptr);
 
-    /**
-     * Destroys a KJobTrackerInterface
-     */
     ~KUiServerJobTracker() override;
 
-    /**
+    /*!
      * Register a new job in this tracker.
      *
-     * @param job the job to register
+     * \a job the job to register
      */
     void registerJob(KJob *job) override;
 
-    /**
+    /*!
      * Unregister a job from this tracker.
      *
-     * @param job the job to unregister
+     * \a job the job to unregister
      */
     void unregisterJob(KJob *job) override;
 
 protected Q_SLOTS:
-    /**
-     * The following slots are inherited from KJobTrackerInterface.
-     */
     void finished(KJob *job) override;
     void suspended(KJob *job) override;
     void resumed(KJob *job) override;
-    virtual void description(KJob *job, const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2) override;
+    void description(KJob *job, const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2) override;
     void infoMessage(KJob *job, const QString &message) override;
     void totalAmount(KJob *job, KJob::Unit unit, qulonglong amount) override;
     void processedAmount(KJob *job, KJob::Unit unit, qulonglong amount) override;
@@ -71,5 +70,6 @@ private:
 
     Q_PRIVATE_SLOT(d, void _k_killJob())
 };
+#endif // KWIDGETS_ENABLE_DEPRECATED_SINCE
 
 #endif
